class AnnouncementsController < ApplicationController
  def index
    list
    render :action => 'list'
  end

  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }

  def list
    @user = session["user"]; @title = "All";
    @announcement_pages, @announcements = paginate :announcements, :per_page => 10 #old!
  end

  def show
    @announcement = Announcement.find(params[:id])
    @user = session["user"]; @title = "Announcement ##{@announcement.id}";
  end

  def new
    @user = session["user"]; @title = "New";
    @announcement = Announcement.new
    
    is_weekday = lambda do |date|
      monday, friday = 1, 5
      date.wday.between?(monday, friday)
    end

    next_weekday = lambda do |date|
      date = date.dup
      until is_weekday.call(date)
        date += 1
      end
      date
    end
      
    @default_start_date = next_weekday.call(Date.today)
    @default_end_date = next_weekday.call(@default_start_date + 3)
  end

  def create
    @user = session["user"]; @title = "Create";
    attrs = params[:announcement]
    attrs['creation_date'] = Time.now
    attrs['creator'] = @user.login
    if !@user.admin?
      attrs['approved'] = false
    end
    # otherwise, whatever the form says.
    @announcement = Announcement.new(attrs)
    if @announcement.save
      flash[:notice] = 'Announcement was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  def edit
    @user = session["user"]; @title = "Edit";
    @announcement = Announcement.find(params[:id])
    @default_start_date = @announcement.start_date
    @default_end_date = @announcement.end_date

    # Block people from editing other people's announcements unless they are an admin.
    if !@user or !@user.admin? && @user.login != @announcement.creator
      flash[:error] = "You must be an administrator or the creator of an announcement to edit it."
      redirect_to :action => 'show', :id => @announcement
    else
      render
    end
  end

  def update
    @user = session["user"]; @title = "Update";
    @announcement = Announcement.find(params[:id])
    attrs = params[:announcement]
    attrs.delete "creator"
    attrs.delete "creation_date"
    attrs.delete "approved" unless @user.admin?
    if @announcement.update_attributes(attrs)
      flash[:notice] = 'Announcement was successfully updated.'
      redirect_to :action => 'show', :id => @announcement
    else
      render :action => 'edit'
    end
  end

  def destroy
    @user = session["user"]; @title = "Destroy";
    Announcement.find(params[:id]).destroy
    redirect_to :action => 'list'
  end
  
  def for
    @user = session["user"];
    
    # Find the right date to display.  Accepts a day parameter or the date_select style of 1i, 2i, 3i.
    @date = if params[:display]
        d = params[:display]
        Date.civil(*((1..3).map {|x| d["day(#{x}i)"].to_i }))
      elsif params[:day] && params[:day] != "today"
        Date.parse(params[:day])
      else
        Date.today
      end

    @human_readable_date = if @date == Date.today
      "Today"
    elsif @date == Date.today.next
      "Tomorrow"
    elsif (@date.yday - Date.today.yday).between? 0, 6
      Date::DAYNAMES[@date.wday]
    else
      @date.to_s
    end
    
    @title = "For #{@human_readable_date}"
    
    @announcements = Announcement.find_all.select do |announcement|
      start_date, end_date = announcement.start_date, announcement.end_date
      @date.between? start_date, end_date and announcement.approved?
    end
  end

  def approve
    @user = session["user"]; @title = "Approve";
    if !@user or !@user.admin?
      flash[:error] = "You must be logged in and an administrator to do that!"
      list
      render :action => :list
      return
    end
    
    @announcements = Announcement.find_all.select do |announcement|
      !announcement.approved? and announcement.end_date >= Date.today
    end
  end

  def update_multiple
    @user = session["user"]; @title = "Update Multiple";
    
    params[:ids].each do |i, attrs|
      announcement = Announcement.find(i)
      attrs.delete "creator"
      attrs.delete "creation_date"
      attrs.delete "approved" unless @user.admin?
      announcement.update_attributes(attrs)
    end
    redirect_to :action => :approve
  end
end
